==> openshift-model-hive-6.7.2-sources.jar: io/fabric8/openshift/api/model/hive/v1/SelectorSyncIdentityProviderListBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class SelectorSyncIdentityProviderListBuilder extends SelectorSyncIdentityProviderListFluentImpl<SelectorSyncIdentityProviderListBuilder> implements VisitableBuilder<SelectorSyncIdentityProviderList,SelectorSyncIdentityProviderListBuilder>{
  public SelectorSyncIdentityProviderListBuilder() {
    this(false);
  }
  public SelectorSyncIdentityProviderListBuilder(Boolean validationEnabled) {
    this(new SelectorSyncIdentityProviderList(), validationEnabled);
  }
  public SelectorSyncIdentityProviderListBuilder(SelectorSyncIdentityProviderListFluent<?> fluent) {
    this(fluent, false);
  }
  public SelectorSyncIdentityProviderListBuilder(SelectorSyncIdentityProviderListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new SelectorSyncIdentityProviderList(), validationEnabled);
  }
  public SelectorSyncIdentityProviderListBuilder(SelectorSyncIdentityProviderListFluent<?> fluent,SelectorSyncIdentityProviderList instance) {
    this(fluent, instance, false);
  }
  public SelectorSyncIdentityProviderListBuilder(SelectorSyncIdentityProviderListFluent<?> fluent,SelectorSyncIdentityProviderList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public SelectorSyncIdentityProviderListBuilder(SelectorSyncIdentityProviderList instance) {
    this(instance,false);
  }
  public SelectorSyncIdentityProviderListBuilder(SelectorSyncIdentityProviderList instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  SelectorSyncIdentityProviderListFluent<?> fluent;
  Boolean validationEnabled;
  public SelectorSyncIdentityProviderList build() {
    SelectorSyncIdentityProviderList buildable = new SelectorSyncIdentityProviderList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-hive-6.8.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/SelectorSyncIdentityProviderListBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class SelectorSyncIdentityProviderListBuilder extends SelectorSyncIdentityProviderListFluent<SelectorSyncIdentityProviderListBuilder> implements VisitableBuilder<SelectorSyncIdentityProviderList,SelectorSyncIdentityProviderListBuilder>{
  public SelectorSyncIdentityProviderListBuilder() {
    this(false);
  }
  public SelectorSyncIdentityProviderListBuilder(Boolean validationEnabled) {
    this(new SelectorSyncIdentityProviderList(), validationEnabled);
  }
  public SelectorSyncIdentityProviderListBuilder(SelectorSyncIdentityProviderListFluent<?> fluent) {
    this(fluent, false);
  }
  public SelectorSyncIdentityProviderListBuilder(SelectorSyncIdentityProviderListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new SelectorSyncIdentityProviderList(), validationEnabled);
  }
  public SelectorSyncIdentityProviderListBuilder(SelectorSyncIdentityProviderListFluent<?> fluent,SelectorSyncIdentityProviderList instance) {
    this(fluent, instance, false);
  }
  public SelectorSyncIdentityProviderListBuilder(SelectorSyncIdentityProviderListFluent<?> fluent,SelectorSyncIdentityProviderList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new SelectorSyncIdentityProviderList());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public SelectorSyncIdentityProviderListBuilder(SelectorSyncIdentityProviderList instance) {
    this(instance,false);
  }
  public SelectorSyncIdentityProviderListBuilder(SelectorSyncIdentityProviderList instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new SelectorSyncIdentityProviderList());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  SelectorSyncIdentityProviderListFluent<?> fluent;
  Boolean validationEnabled;
  public SelectorSyncIdentityProviderList build() {
    SelectorSyncIdentityProviderList buildable = new SelectorSyncIdentityProviderList(fluent.getApiVersion(),fluent.buildItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
